==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fsent_confirmation-1.4-1.2.tar.gz: sent_confirmation/setup.php <==
<?php


function squirrelmail_plugin_init_sent_confirmation()
{

	global $squirrelmail_plugin_hooks;

        $squirrelmail_plugin_hooks['compose_send']['sent_confirmation']            = 'sent_conf_message_sent';
        $squirrelmail_plugin_hooks['generic_header']['sent_confirmation']          = 'sent_conf_check_is_sent';
        $squirrelmail_plugin_hooks['compose_bottom']['sent_confirmation']          = 'sent_conf_compose_bottom';


        $squirrelmail_plugin_hooks['options_display_inside']['sent_confirmation']  = 'sent_conf_show_options';
        $squirrelmail_plugin_hooks['options_display_save']['sent_confirmation']    = 'sent_conf_save_options';


}



//
//
function sent_confirmation_version() {

   return '1.4';

}



// This is the text that appears on the option page
//
function sent_conf_show_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options();

}



// Here we save the user's sent_confirmation preferences
//
function sent_conf_save_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options_save();

}



// set flag indicating message was sent
function sent_conf_message_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_message_sent_do();

}



// 
//
function sent_conf_check_is_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_check_is_sent_do();

}



// 
//
function sent_conf_compose_bottom() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_compose_bottom_do();

}


?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fsent_confirmation-1.5-1.2.tar.gz: sent_confirmation/setup.php <==
<?php


function squirrelmail_plugin_init_sent_confirmation()
{

	global $squirrelmail_plugin_hooks;

        $squirrelmail_plugin_hooks['compose_send']['sent_confirmation']            = 'sent_conf_message_sent';
        $squirrelmail_plugin_hooks['generic_header']['sent_confirmation']          = 'sent_conf_check_is_sent';

// This was causing PHP warnings when replying so don't use 
// it for now - it wasn't really necessary, just to be extra 
// extra safe anyway (turn off sent flag)
//        $squirrelmail_plugin_hooks['compose_bottom']['sent_confirmation']          = 'sent_conf_compose_bottom';


        $squirrelmail_plugin_hooks['options_display_inside']['sent_confirmation']  = 'sent_conf_show_options';
        $squirrelmail_plugin_hooks['options_display_save']['sent_confirmation']    = 'sent_conf_save_options';


}



//
//
function sent_confirmation_version() {

   return '1.5';

}



// This is the text that appears on the option page
//
function sent_conf_show_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options();

}



// Here we save the user's sent_confirmation preferences
//
function sent_conf_save_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options_save();

}



// set flag indicating message was sent
function sent_conf_message_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_message_sent_do();

}



// 
//
function sent_conf_check_is_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_check_is_sent_do();

}



// 
//
function sent_conf_compose_bottom() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_compose_bottom_do();

}


?>
